@@ -1,4 +1,4 @@
-`fitted.Arimax` <-
+`fitted.Arima` <-
 function (object,...) 
 {
 fitted=eval(object$call$x)-residuals(object)
